pub(super) fn code_lenses(
file_uri: &Url,
file_text: &str,
root: &Path,
project_cache: Option<&ProjectCache>,
) -> Vec<CodeLens>Expand description
Build code lenses for tests and explain targets in the file.
Returns an empty vec if the file is not under models/<db>/<schema>/ or
the object is not found in the project cache.